package com.swmansion.rnscreens;

import android.content.Context;
import android.graphics.Canvas;
import android.view.View;
import androidx.fragment.app.FragmentTransaction;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.uimanager.UIManagerModule;
import com.facebook.react.uimanager.events.EventDispatcher;
import com.swmansion.rnscreens.Screen;
import com.swmansion.rnscreens.events.StackFinishTransitioningEvent;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.TypeIntrinsics;
import kotlin.ranges.RangesKt;

public final class ScreenStack extends ScreenContainer<ScreenStackFragment> {
    public static final Companion Companion = new Companion(null);
    private final List<DrawingOp> drawingOpPool = new ArrayList();
    private List<DrawingOp> drawingOps = new ArrayList();
    private boolean goingForward;
    private boolean isDetachingCurrentScreen;
    private final Set<ScreenStackFragment> mDismissed = new HashSet();
    private boolean mRemovalTransitionStarted;
    private final ArrayList<ScreenStackFragment> mStack = new ArrayList<>();
    private ScreenStackFragment mTopScreen;
    private int previousChildrenCount;
    private boolean reverseLastTwoChildren;

    public /* synthetic */ class WhenMappings {
        public static final /* synthetic */ int[] $EnumSwitchMapping$0;

        static {
            int[] iArr = new int[Screen.StackAnimation.values().length];
            iArr[Screen.StackAnimation.DEFAULT.ordinal()] = 1;
            iArr[Screen.StackAnimation.NONE.ordinal()] = 2;
            iArr[Screen.StackAnimation.FADE.ordinal()] = 3;
            iArr[Screen.StackAnimation.SLIDE_FROM_RIGHT.ordinal()] = 4;
            iArr[Screen.StackAnimation.SLIDE_FROM_LEFT.ordinal()] = 5;
            iArr[Screen.StackAnimation.SLIDE_FROM_BOTTOM.ordinal()] = 6;
            iArr[Screen.StackAnimation.FADE_FROM_BOTTOM.ordinal()] = 7;
            $EnumSwitchMapping$0 = iArr;
        }
    }

    public ScreenStack(Context context) {
        super(context);
    }

    public final boolean getGoingForward() {
        return this.goingForward;
    }

    public final void setGoingForward(boolean z) {
        this.goingForward = z;
    }

    public final void dismiss(ScreenStackFragment screenStackFragment) {
        Intrinsics.checkNotNullParameter(screenStackFragment, "screenFragment");
        this.mDismissed.add(screenStackFragment);
        performUpdatesNow();
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public Screen getTopScreen() {
        ScreenStackFragment screenStackFragment = this.mTopScreen;
        if (screenStackFragment != null) {
            return screenStackFragment.getScreen();
        }
        return null;
    }

    public final Screen getRootScreen() {
        int screenCount = getScreenCount();
        for (int i = 0; i < screenCount; i++) {
            Screen screenAt = getScreenAt(i);
            if (!CollectionsKt.contains(this.mDismissed, screenAt.getFragment())) {
                return screenAt;
            }
        }
        throw new IllegalStateException("Stack has no root screen set");
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public ScreenStackFragment adapt(Screen screen) {
        Intrinsics.checkNotNullParameter(screen, "screen");
        return new ScreenStackFragment(screen);
    }

    public void startViewTransition(View view) {
        Intrinsics.checkNotNullParameter(view, "view");
        super.startViewTransition(view);
        this.mRemovalTransitionStarted = true;
    }

    public void endViewTransition(View view) {
        Intrinsics.checkNotNullParameter(view, "view");
        super.endViewTransition(view);
        if (this.mRemovalTransitionStarted) {
            this.mRemovalTransitionStarted = false;
            dispatchOnFinishTransitioning();
        }
    }

    public final void onViewAppearTransitionEnd() {
        if (!this.mRemovalTransitionStarted) {
            dispatchOnFinishTransitioning();
        }
    }

    private final void dispatchOnFinishTransitioning() {
        EventDispatcher eventDispatcher;
        Context context = getContext();
        Objects.requireNonNull(context, "null cannot be cast to non-null type com.facebook.react.bridge.ReactContext");
        UIManagerModule uIManagerModule = (UIManagerModule) ((ReactContext) context).getNativeModule(UIManagerModule.class);
        if (uIManagerModule != null && (eventDispatcher = uIManagerModule.getEventDispatcher()) != null) {
            eventDispatcher.dispatchEvent(new StackFinishTransitioningEvent(getId()));
        }
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public void removeScreenAt(int i) {
        TypeIntrinsics.asMutableCollection(this.mDismissed).remove(getScreenAt(i).getFragment());
        super.removeScreenAt(i);
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public void removeAllScreens() {
        this.mDismissed.clear();
        super.removeAllScreens();
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public boolean hasScreen(ScreenFragment screenFragment) {
        return super.hasScreen(screenFragment) && !CollectionsKt.contains(this.mDismissed, screenFragment);
    }

    /* JADX WARNING: Removed duplicated region for block: B:52:0x00b4  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x015e  */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x0186  */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x01a1  */
    @Override // com.swmansion.rnscreens.ScreenContainer
    public void onUpdate() {
        boolean z;
        FragmentTransaction createTransaction;
        Iterator<ScreenStackFragment> it;
        Iterator it2;
        ScreenStackFragment screenStackFragment;
        Screen screen;
        Screen screen2;
        this.isDetachingCurrentScreen = false;
        int size = this.mScreenFragments.size() - 1;
        Screen.StackAnimation stackAnimation = null;
        ScreenStackFragment screenStackFragment2 = null;
        ScreenStackFragment screenStackFragment3 = null;
        if (size >= 0) {
            while (true) {
                int i = size - 1;
                Object obj = this.mScreenFragments.get(size);
                Intrinsics.checkNotNullExpressionValue(obj, "mScreenFragments[i]");
                ScreenStackFragment screenStackFragment4 = (ScreenStackFragment) obj;
                if (!this.mDismissed.contains(screenStackFragment4)) {
                    if (screenStackFragment2 == null) {
                        screenStackFragment2 = screenStackFragment4;
                    } else {
                        screenStackFragment3 = screenStackFragment4;
                    }
                    if (!Companion.isTransparent(screenStackFragment4)) {
                        break;
                    }
                }
                if (i < 0) {
                    break;
                }
                size = i;
            }
        }
        boolean z2 = true;
        if (!CollectionsKt.contains(this.mStack, screenStackFragment2)) {
            ScreenStackFragment screenStackFragment5 = this.mTopScreen;
            if (screenStackFragment5 != null && screenStackFragment2 != null) {
                z = (screenStackFragment5 != null && this.mScreenFragments.contains(screenStackFragment5)) || (screenStackFragment2.getScreen().getReplaceAnimation() == Screen.ReplaceAnimation.PUSH);
                if (z) {
                    stackAnimation = screenStackFragment2.getScreen().getStackAnimation();
                } else {
                    ScreenStackFragment screenStackFragment6 = this.mTopScreen;
                    if (!(screenStackFragment6 == null || (screen2 = screenStackFragment6.getScreen()) == null)) {
                        stackAnimation = screen2.getStackAnimation();
                    }
                }
                createTransaction = createTransaction();
                if (stackAnimation != null) {
                    if (!z) {
                        switch (WhenMappings.$EnumSwitchMapping$0[stackAnimation.ordinal()]) {
                            case 1:
                                createTransaction.setCustomAnimations(R.anim.rns_default_exit_in, R.anim.rns_default_exit_out);
                                break;
                            case 2:
                                createTransaction.setCustomAnimations(R.anim.rns_no_animation_20, R.anim.rns_no_animation_20);
                                break;
                            case 3:
                                createTransaction.setCustomAnimations(R.anim.rns_fade_in, R.anim.rns_fade_out);
                                break;
                            case 4:
                                createTransaction.setCustomAnimations(R.anim.rns_slide_in_from_left, R.anim.rns_slide_out_to_right);
                                break;
                            case 5:
                                createTransaction.setCustomAnimations(R.anim.rns_slide_in_from_right, R.anim.rns_slide_out_to_left);
                                break;
                            case 6:
                                createTransaction.setCustomAnimations(R.anim.rns_no_animation_medium, R.anim.rns_slide_out_to_bottom);
                                break;
                            case 7:
                                createTransaction.setCustomAnimations(R.anim.rns_no_animation_250, R.anim.rns_fade_to_bottom);
                                break;
                        }
                    } else {
                        switch (WhenMappings.$EnumSwitchMapping$0[stackAnimation.ordinal()]) {
                            case 1:
                                createTransaction.setCustomAnimations(R.anim.rns_default_enter_in, R.anim.rns_default_enter_out);
                                break;
                            case 2:
                                createTransaction.setCustomAnimations(R.anim.rns_no_animation_20, R.anim.rns_no_animation_20);
                                break;
                            case 3:
                                createTransaction.setCustomAnimations(R.anim.rns_fade_in, R.anim.rns_fade_out);
                                break;
                            case 4:
                                createTransaction.setCustomAnimations(R.anim.rns_slide_in_from_right, R.anim.rns_slide_out_to_left);
                                break;
                            case 5:
                                createTransaction.setCustomAnimations(R.anim.rns_slide_in_from_left, R.anim.rns_slide_out_to_right);
                                break;
                            case 6:
                                createTransaction.setCustomAnimations(R.anim.rns_slide_in_from_bottom, R.anim.rns_no_animation_medium);
                                break;
                            case 7:
                                createTransaction.setCustomAnimations(R.anim.rns_fade_from_bottom, R.anim.rns_no_animation_350);
                                break;
                        }
                    }
                }
                this.goingForward = z;
                if (z && screenStackFragment2 != null && Companion.needsDrawReordering(screenStackFragment2) && screenStackFragment3 == null) {
                    this.isDetachingCurrentScreen = true;
                }
                it = this.mStack.iterator();
                while (it.hasNext()) {
                    ScreenStackFragment next = it.next();
                    if (!this.mScreenFragments.contains(next) || this.mDismissed.contains(next)) {
                        createTransaction.remove(next);
                    }
                }
                it2 = this.mScreenFragments.iterator();
                while (it2.hasNext() && (screenStackFragment = (ScreenStackFragment) it2.next()) != screenStackFragment3) {
                    if (screenStackFragment != screenStackFragment2 && !this.mDismissed.contains(screenStackFragment)) {
                        createTransaction.remove(screenStackFragment);
                    }
                }
                if (screenStackFragment3 == null && !screenStackFragment3.isAdded()) {
                    Iterator it3 = this.mScreenFragments.iterator();
                    while (it3.hasNext()) {
                        ScreenStackFragment screenStackFragment7 = (ScreenStackFragment) it3.next();
                        if (z2) {
                            if (screenStackFragment7 == screenStackFragment3) {
                                z2 = false;
                            }
                        }
                        createTransaction.add(getId(), screenStackFragment7).runOnCommit(new ScreenStack$$ExternalSyntheticLambda0(screenStackFragment2));
                    }
                } else if (screenStackFragment2 != null && !screenStackFragment2.isAdded()) {
                    createTransaction.add(getId(), screenStackFragment2);
                }
                this.mTopScreen = screenStackFragment2;
                this.mStack.clear();
                this.mStack.addAll(this.mScreenFragments);
                turnOffA11yUnderTransparentScreen(screenStackFragment3);
                createTransaction.commitNowAllowingStateLoss();
            } else if (screenStackFragment5 == null && screenStackFragment2 != null) {
                stackAnimation = Screen.StackAnimation.NONE;
                this.goingForward = true;
            }
        } else {
            ScreenStackFragment screenStackFragment8 = this.mTopScreen;
            if (screenStackFragment8 != null && !Intrinsics.areEqual(screenStackFragment8, screenStackFragment2)) {
                ScreenStackFragment screenStackFragment9 = this.mTopScreen;
                if (!(screenStackFragment9 == null || (screen = screenStackFragment9.getScreen()) == null)) {
                    stackAnimation = screen.getStackAnimation();
                }
                z = false;
                createTransaction = createTransaction();
                if (stackAnimation != null) {
                }
                this.goingForward = z;
                this.isDetachingCurrentScreen = true;
                it = this.mStack.iterator();
                while (it.hasNext()) {
                }
                it2 = this.mScreenFragments.iterator();
                while (it2.hasNext()) {
                    createTransaction.remove(screenStackFragment);
                }
                if (screenStackFragment3 == null) {
                }
                createTransaction.add(getId(), screenStackFragment2);
                this.mTopScreen = screenStackFragment2;
                this.mStack.clear();
                this.mStack.addAll(this.mScreenFragments);
                turnOffA11yUnderTransparentScreen(screenStackFragment3);
                createTransaction.commitNowAllowingStateLoss();
            }
        }
        z = true;
        createTransaction = createTransaction();
        if (stackAnimation != null) {
        }
        this.goingForward = z;
        this.isDetachingCurrentScreen = true;
        it = this.mStack.iterator();
        while (it.hasNext()) {
        }
        it2 = this.mScreenFragments.iterator();
        while (it2.hasNext()) {
        }
        if (screenStackFragment3 == null) {
        }
        createTransaction.add(getId(), screenStackFragment2);
        this.mTopScreen = screenStackFragment2;
        this.mStack.clear();
        this.mStack.addAll(this.mScreenFragments);
        turnOffA11yUnderTransparentScreen(screenStackFragment3);
        createTransaction.commitNowAllowingStateLoss();
    }

    /* renamed from: onUpdate$lambda-2$lambda-1 */
    public static final void m38onUpdate$lambda2$lambda1(ScreenStackFragment screenStackFragment) {
        Screen screen;
        if (screenStackFragment != null && (screen = screenStackFragment.getScreen()) != null) {
            screen.bringToFront();
        }
    }

    private final void turnOffA11yUnderTransparentScreen(ScreenStackFragment screenStackFragment) {
        ScreenStackFragment screenStackFragment2;
        if (this.mScreenFragments.size() > 1 && screenStackFragment != null && (screenStackFragment2 = this.mTopScreen) != null && Companion.isTransparent(screenStackFragment2)) {
            for (ScreenStackFragment screenStackFragment3 : CollectionsKt.asReversed(CollectionsKt.slice((List) this.mScreenFragments, RangesKt.until(0, this.mScreenFragments.size() - 1)))) {
                screenStackFragment3.getScreen().changeAccessibilityMode(4);
                if (Intrinsics.areEqual(screenStackFragment3, screenStackFragment)) {
                    break;
                }
            }
        }
        Screen topScreen = getTopScreen();
        if (topScreen != null) {
            topScreen.changeAccessibilityMode(0);
        }
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public void notifyContainerUpdate() {
        Iterator<ScreenStackFragment> it = this.mStack.iterator();
        while (it.hasNext()) {
            it.next().onContainerUpdate();
        }
    }

    @Override // com.swmansion.rnscreens.ScreenContainer
    public void removeView(View view) {
        Intrinsics.checkNotNullParameter(view, "view");
        if (this.isDetachingCurrentScreen) {
            this.isDetachingCurrentScreen = false;
            this.reverseLastTwoChildren = true;
        }
        super.removeView(view);
    }

    private final void drawAndRelease() {
        List<DrawingOp> list = this.drawingOps;
        this.drawingOps = new ArrayList();
        for (DrawingOp drawingOp : list) {
            drawingOp.draw();
            this.drawingOpPool.add(drawingOp);
        }
    }

    public void dispatchDraw(Canvas canvas) {
        Intrinsics.checkNotNullParameter(canvas, "canvas");
        super.dispatchDraw(canvas);
        if (this.drawingOps.size() < this.previousChildrenCount) {
            this.reverseLastTwoChildren = false;
        }
        this.previousChildrenCount = this.drawingOps.size();
        if (this.reverseLastTwoChildren && this.drawingOps.size() >= 2) {
            List<DrawingOp> list = this.drawingOps;
            Collections.swap(list, list.size() - 1, this.drawingOps.size() - 2);
        }
        drawAndRelease();
    }

    public boolean drawChild(Canvas canvas, View view, long j) {
        Intrinsics.checkNotNullParameter(canvas, "canvas");
        Intrinsics.checkNotNullParameter(view, "child");
        this.drawingOps.add(obtainDrawingOp().set(canvas, view, j));
        return true;
    }

    private final void performDraw(DrawingOp drawingOp) {
        super.drawChild(drawingOp.getCanvas(), drawingOp.getChild(), drawingOp.getDrawingTime());
    }

    private final DrawingOp obtainDrawingOp() {
        if (this.drawingOpPool.isEmpty()) {
            return new DrawingOp();
        }
        List<DrawingOp> list = this.drawingOpPool;
        return list.remove(list.size() - 1);
    }

    public final class DrawingOp {
        private Canvas canvas;
        private View child;
        private long drawingTime;

        public DrawingOp() {
            ScreenStack.this = r1;
        }

        public final Canvas getCanvas() {
            return this.canvas;
        }

        public final void setCanvas(Canvas canvas2) {
            this.canvas = canvas2;
        }

        public final View getChild() {
            return this.child;
        }

        public final void setChild(View view) {
            this.child = view;
        }

        public final long getDrawingTime() {
            return this.drawingTime;
        }

        public final void setDrawingTime(long j) {
            this.drawingTime = j;
        }

        public final DrawingOp set(Canvas canvas2, View view, long j) {
            this.canvas = canvas2;
            this.child = view;
            this.drawingTime = j;
            return this;
        }

        public final void draw() {
            ScreenStack.this.performDraw(this);
            this.canvas = null;
            this.child = null;
            this.drawingTime = 0;
        }
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        private final boolean isTransparent(ScreenStackFragment screenStackFragment) {
            return screenStackFragment.getScreen().getStackPresentation() == Screen.StackPresentation.TRANSPARENT_MODAL;
        }

        private final boolean needsDrawReordering(ScreenStackFragment screenStackFragment) {
            return screenStackFragment.getScreen().getStackAnimation() == Screen.StackAnimation.SLIDE_FROM_BOTTOM || screenStackFragment.getScreen().getStackAnimation() == Screen.StackAnimation.FADE_FROM_BOTTOM;
        }
    }
}
