package expo.modules.systemui;

import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import androidx.autofill.HintConstants;
import com.facebook.react.bridge.BaseJavaModule;
import com.facebook.react.uimanager.ViewProps;
import expo.modules.core.ExportedModule;
import expo.modules.core.ModuleRegistry;
import expo.modules.core.Promise;
import expo.modules.core.errors.CurrentActivityNotFoundException;
import expo.modules.core.interfaces.ActivityProvider;
import expo.modules.core.interfaces.ExpoMethod;
import java.util.Arrays;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.StringCompanionObject;

@Metadata(d1 = {"\u0000L\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000e\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0010\b\n\u0002\b\u0002\u0018\u0000 \u001a2\u00020\u0001:\u0001\u001aB\r\u0012\u0006\u0010\u0002\u001a\u00020\u0003¢\u0006\u0002\u0010\u0004J\u0010\u0010\u0007\u001a\u00020\b2\u0006\u0010\t\u001a\u00020\nH\u0007J\b\u0010\u000b\u001a\u00020\fH\u0016J\u0010\u0010\r\u001a\u00020\b2\u0006\u0010\u000e\u001a\u00020\u000fH\u0016J3\u0010\u0010\u001a\u00020\b2\u0006\u0010\t\u001a\u00020\n2!\u0010\u0011\u001a\u001d\u0012\u0013\u0012\u00110\u0013¢\u0006\f\b\u0014\u0012\b\b\u0015\u0012\u0004\b\b(\u0016\u0012\u0004\u0012\u00020\b0\u0012H\u0002J\u0018\u0010\u0017\u001a\u00020\b2\u0006\u0010\u0018\u001a\u00020\u00192\u0006\u0010\t\u001a\u00020\nH\u0007R\u000e\u0010\u0005\u001a\u00020\u0006X.¢\u0006\u0002\n\u0000¨\u0006\u001b"}, d2 = {"Lexpo/modules/systemui/SystemUIModule;", "Lexpo/modules/core/ExportedModule;", "context", "Landroid/content/Context;", "(Landroid/content/Context;)V", "activityProvider", "Lexpo/modules/core/interfaces/ActivityProvider;", "getBackgroundColorAsync", "", BaseJavaModule.METHOD_TYPE_PROMISE, "Lexpo/modules/core/Promise;", "getName", "", "onCreate", "moduleRegistry", "Lexpo/modules/core/ModuleRegistry;", "safeRunOnUiThread", "block", "Lkotlin/Function1;", "Landroid/app/Activity;", "Lkotlin/ParameterName;", HintConstants.AUTOFILL_HINT_NAME, "activity", "setBackgroundColorAsync", ViewProps.COLOR, "", "Companion", "expo-system-ui_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: SystemUIModule.kt */
public final class SystemUIModule extends ExportedModule {
    public static final Companion Companion = new Companion(null);
    private static final String ERROR_TAG = "ERR_SYSTEM_UI";
    private static final String NAME = "ExpoSystemUI";
    private ActivityProvider activityProvider;

    @Override // expo.modules.core.ExportedModule
    public String getName() {
        return NAME;
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public SystemUIModule(Context context) {
        super(context);
        Intrinsics.checkNotNullParameter(context, "context");
    }

    @Override // expo.modules.core.interfaces.RegistryLifecycleListener, expo.modules.core.ExportedModule
    public void onCreate(ModuleRegistry moduleRegistry) {
        Intrinsics.checkNotNullParameter(moduleRegistry, "moduleRegistry");
        ActivityProvider activityProvider2 = (ActivityProvider) moduleRegistry.getModule(ActivityProvider.class);
        if (activityProvider2 != null) {
            this.activityProvider = activityProvider2;
            return;
        }
        throw new IllegalStateException("Could not find implementation for ActivityProvider.");
    }

    private final void safeRunOnUiThread(Promise promise, Function1<? super Activity, Unit> function1) {
        ActivityProvider activityProvider2 = this.activityProvider;
        if (activityProvider2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("activityProvider");
            activityProvider2 = null;
        }
        Activity currentActivity = activityProvider2.getCurrentActivity();
        if (currentActivity == null) {
            promise.reject(new CurrentActivityNotFoundException());
        } else {
            currentActivity.runOnUiThread(new SystemUIModule$$ExternalSyntheticLambda0(function1, currentActivity));
        }
    }

    /* access modifiers changed from: private */
    /* renamed from: safeRunOnUiThread$lambda-0  reason: not valid java name */
    public static final void m121safeRunOnUiThread$lambda0(Function1 function1, Activity activity) {
        Intrinsics.checkNotNullParameter(function1, "$block");
        Intrinsics.checkNotNullExpressionValue(activity, "activity");
        function1.invoke(activity);
    }

    @ExpoMethod
    public final void setBackgroundColorAsync(int i, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        safeRunOnUiThread(promise, new SystemUIModule$setBackgroundColorAsync$1(i, promise));
    }

    @ExpoMethod
    public final void getBackgroundColorAsync(Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        safeRunOnUiThread(promise, new SystemUIModule$getBackgroundColorAsync$1(promise));
    }

    @Metadata(d1 = {"\u0000\u001a\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0002\b\u0003\n\u0002\u0010\b\n\u0000\b\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u000e\u0010\u0006\u001a\u00020\u00042\u0006\u0010\u0007\u001a\u00020\bR\u000e\u0010\u0003\u001a\u00020\u0004XT¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0004XT¢\u0006\u0002\n\u0000¨\u0006\t"}, d2 = {"Lexpo/modules/systemui/SystemUIModule$Companion;", "", "()V", "ERROR_TAG", "", "NAME", "colorToHex", ViewProps.COLOR, "", "expo-system-ui_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: SystemUIModule.kt */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final String colorToHex(int i) {
            StringCompanionObject stringCompanionObject = StringCompanionObject.INSTANCE;
            String format = String.format("#%02x%02x%02x", Arrays.copyOf(new Object[]{Integer.valueOf(Color.red(i)), Integer.valueOf(Color.green(i)), Integer.valueOf(Color.blue(i))}, 3));
            Intrinsics.checkNotNullExpressionValue(format, "format(format, *args)");
            return format;
        }
    }
}
